// @flow

import parser from '../src/parser';

test('Variable declaration', () => {
  const code1 = 'const a = 4';
  const expected1 = `const - a declaration of local constant, which value you cannot change (immutable)
a - name (identifier) of variable
4 - value of variable`;

  const code2 = 'let b = 5';
  const expected2 = `let - a declaration of local variable, which value you can change (mutable)
b - name (identifier) of variable
5 - value of variable`;

  expect(parser(code1)).toBe(expected1);
  expect(parser(code2)).toBe(expected2);
});

test('Function declaration', () => {
  const code = 'const foo = (n, m) => n + 2 * m';
  const expected = `const - a declaration of local constant, which value you cannot change (immutable)
foo - name (identifier) of variable
Declaration of function:
  n, m - parameters of function
  Body of function:
    n + 2 * m - binary expression:
      + - operation of binary expression (addition)
      n - name (identifier) of variable
      2 * m - binary expression:
        * - operation of binary expression (multiplication)
        2 - value of variable
        m - name (identifier) of variable`;

  expect(parser(code)).toBe(expected);
});

test('If statement', () => {
  const code = 'if (2 === 2) { "Yeah!" }';
  const expected = `if - The if statement executes a statement if a specified condition is truthy. If the condition is falsy, another statement can be executed
2 === 2 - condition of if statemant, which should always return true or false
Statement that is executed if condition is truthy:
  Yeah! - value of variable`;

  expect(parser(code)).toBe(expected);
});

test('Function call', () => {
  const code = 'foo(bar, 2)';
  const expected = `Calling a function:
foo - name of function
bar, 2 - arguments of function`;

  expect(parser(code)).toBe(expected);
})
