import nodeBuilder from './nodeBuilder';
import addTabs from './addTabs';

export default class {
  constructor({ operator, left, right }, level) {
    this.operator = operator;
    this.left = left;
    this.right = right;
    this.level = level;
  }

  toString() {
    const left = nodeBuilder(this.left).toString();
    const right = nodeBuilder(this.right).toString();
    return `${left} ${this.operator} ${right}`;
  }

  explain() {
    const expression = `${this.toString()} - binary expression:`;
    const operation = `${this.operator} - operation of binary expression (${this.operatorExplain()})`;
    const left = nodeBuilder(this.left, this.level + 1).explain();
    const right = nodeBuilder(this.right, this.level + 1).explain();
    return [expression, ...[operation, left, right].map(el => addTabs(el, this.level))].join('\n');
  }

  operatorExplain() {
    const operators = {
      '+': 'addition',
      '-': 'substraction',
      '*': 'multiplication',
      '/': 'division',
    };

    return operators[this.operator];
  }
}
